import * as zod from 'zod';

declare const BIGINT_ARRAY_TYPES: readonly ["signed", "unsigned"];
type BigIntArrayType = (typeof BIGINT_ARRAY_TYPES)[number];
declare const BIGINT64_ARRAY_SCHEMA: zod.ZodType<BigInt64Array, zod.ZodTypeDef, BigInt64Array>;
declare const BIGUINT64_ARRAY_SCHEMA: zod.ZodType<BigUint64Array, zod.ZodTypeDef, BigUint64Array>;
declare const BIGINT_ARRAY_SCHEMAS: {
    readonly signed: zod.ZodType<BigInt64Array, zod.ZodTypeDef, BigInt64Array>;
    readonly unsigned: zod.ZodType<BigUint64Array, zod.ZodTypeDef, BigUint64Array>;
};
interface BigIntArrays {
    signed: BigInt64Array;
    unsigned: BigUint64Array;
}
type BigIntArray<Type extends BigIntArrayType> = BigIntArrays[Type];
type BigIntArrayOptions<Type extends BigIntArrayType> = {
    type: Type;
};
declare function validateBigIntArray<Type extends BigIntArrayType>(value: unknown, options: BigIntArrayOptions<Type>): asserts value is BigIntArray<Type>;
declare function isBigIntArray<Type extends BigIntArrayType>(value: unknown, options: BigIntArrayOptions<Type>): value is BigIntArray<Type>;

export { BIGINT64_ARRAY_SCHEMA, BIGINT_ARRAY_SCHEMAS, BIGINT_ARRAY_TYPES, BIGUINT64_ARRAY_SCHEMA, BigIntArray, BigIntArrayType, BigIntArrays, isBigIntArray, validateBigIntArray };
